Przycisk "Wstaw zdjęcie"

Przycisk "Wstaw łącze" | Spis treści

Przycisk "Wstaw zdjęcie" otwiera okno pokazane poniżej.
Należy podać adres URL lub scieżkę dostępu do zdjęcia które ma być wstawione i podać krótki opis zdjęcia, jest on wyświetlany jako alternatyny tekstowy opis zdjęcia umieszczonego na stronie.
Opis pól:

Adres URL lub ścieżka dostępu do zdjęcia | URL/scieżka dostępu do zdjęcia.
Opis zdjęcia | Tekst opisujący zdjęcia.
Wymiary | Długość/szerokość zdjęcia .
Wyrównanie | Wyrównanie zdjęcia, użyteczne przy zawijaniu tekstu wokół zdjęcia.
Krawędzie | Grubość krawędzi.
Odstęp poziomy | Odstęp poziomy, pomocne przy zawijaniu tesktu wokół zdjęcia.
Odstęp pionowy | Odstęp pionowy, pomocne przy zawijaniu tesktu wokół zdjęcia.

Idź do: Spis treści | Do góry